# -*- coding: utf-8
__title__ = 'CeleryBeat Status'
__version__ = '0.0.10'
__author__ = 'Vinta Software'
__license__ = 'MIT License'
__copyright__ = 'Copyright 2017 Vinta Serviços e Soluções Tecnológicas Ltda'

# Version synonym
VERSION = __version__
